@@ -1,22 +1,8 @@
 /*
-    Copyright 2014-2015 Harald Sitter <sitter@kde.org>
-    Copyright 2016 David Rosca <nowrep@gmail.com>
+    SPDX-FileCopyrightText: 2014-2015 Harald Sitter <sitter@kde.org>
+    SPDX-FileCopyrightText: 2016 David Rosca <nowrep@gmail.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #ifndef PULSEAUDIO_H
@@ -25,17 +11,19 @@
 #include <QAbstractListModel>
 
 #include "maps.h"
+#include "sink.h"
+#include "source.h"
 
 namespace QPulseAudio
 {
-    class Context;
+class Context;
 
 class AbstractModel : public QAbstractListModel
 {
     Q_OBJECT
 public:
     enum ItemRole {
-        PulseObjectRole = Qt::UserRole + 1
+        PulseObjectRole = Qt::UserRole + 1,
     };
     Q_PROPERTY(int count READ rowCount NOTIFY countChanged)
 
@@ -73,7 +61,7 @@ private:
 private:
     // Prevent leaf-classes from default constructing as we want to enforce
     // them passing us a context or explicit nullptrs.
-    AbstractModel() {}
+    AbstractModel() = default;
 };
 
 class CardModel : public AbstractModel
@@ -90,7 +78,7 @@ class SinkModel : public AbstractModel
     Q_PROPERTY(QPulseAudio::Sink *preferredSink READ preferredSink NOTIFY preferredSinkChanged)
 public:
     enum ItemRole {
-        SortByDefaultRole = PulseObjectRole + 1
+        SortByDefaultRole = PulseObjectRole + 1,
     };
     Q_ENUM(ItemRole)
 
@@ -125,7 +113,7 @@ class SourceModel : public AbstractModel
     Q_PROPERTY(QPulseAudio::Source *defaultSource READ defaultSource NOTIFY defaultSourceChanged)
 public:
     enum ItemRole {
-        SortByDefaultRole = PulseObjectRole + 1
+        SortByDefaultRole = PulseObjectRole + 1,
     };
     Q_ENUM(ItemRole)
 
